@@ -1,6 +1,10 @@
-#include "xmule.h"
-#include "types.h"
-#include "AddFileThread.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "types.h"
+#	include "AddFileThread.h"
+#endif
 
 struct UnknownFile_Struct
 {
