@@ -19,12 +19,16 @@
 //
 
 //#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "AddFriend.h"
-#include "Friend.h"
-#include "otherfunctions.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#  include "wintypes.h"
+#  include "xmule.h"
+#  include "AddFriend.h"
+#  include "Friend.h"
+#  include "otherfunctions.h"
+#  include "muuli_wdr.h"
+#endif
 
 #ifdef _DEBUG
 
