@@ -1,9 +1,11 @@
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "BarShader.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "BarShader.h"
+#endif
+
 #include <math.h>
-#include "math.h"
 
 #ifdef _DEBUG
 #undef THIS_FILE
