@@ -15,17 +15,21 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#include "wintypes.h"
-#include "xmule.h"
-#include "ListenSocket.h"
-#include "opcodes.h"
-#include "KnownFile.h"
-#include "SharedFileList.h"
-#include "UploadQueue.h"
-#include "updownclient.h"
-#include "ClientList.h"
-#include "Friend.h"
-#include "otherfunctions.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ListenSocket.h"
+#	include "opcodes.h"
+#	include "KnownFile.h"
+#	include "SharedFileList.h"
+#	include "UploadQueue.h"
+#	include "updownclient.h"
+#	include "ClientList.h"
+#	include "Friend.h"
+#	include "otherfunctions.h"
+#endif
 
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -577,7 +581,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	data->Write(&tagcount,4);
 	CTag tag(ET_COMPRESSION,1);
 	tag.WriteTagToFile(data);
-	CTag tag2(ET_UDPVER, 3); /* From aMule 1.1.1 */
+	CTag tag2(ET_UDPVER, 3);
 	tag2.WriteTagToFile(data);
 	CTag tag3(ET_UDPPORT,theApp.glob_prefs->GetUDPPort());
 	tag3.WriteTagToFile(data);
@@ -585,9 +589,9 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer){
 	tag4.WriteTagToFile(data);
 	CTag tag5(ET_COMMENTS,1);
 	tag5.WriteTagToFile(data);
-	CTag tag6(ET_EXTENDEDREQUEST, 2); /* From aMule 1.1.1 */
+	CTag tag6(ET_EXTENDEDREQUEST, 2);
 	tag6.WriteTagToFile(data);
-	CTag tag7(ET_COMPATABLECLIENT, 2);
+	CTag tag7(ET_COMPATABLECLIENT,2);
 	tag7.WriteTagToFile(data);
 	// Maella end
 	Packet* packet = new Packet(data,OP_EMULEPROT);
