@@ -1,3 +1,8 @@
+/* For whatever reason, this file compiles *faster* when precompiled headers
+   are *not* used.  ::shrug::
+   -- HopeSeekr
+*/
+
 /////////////////////////////////////////////////////////////////////////////
 // Name:        file.cpp
 // Purpose:     wxFile - encapsulates low-level "file descriptor"
@@ -5,7 +10,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: CFile.cpp,v 1.9 2003/07/13 15:48:40 madcat_ Exp $
+// RCS-ID:      $Id: CFile.cpp,v 1.10 2004/01/23 12:41:46 HopeSeekr Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -22,6 +27,8 @@
 // setting __USE_GNU 
 // (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
 #include "wx/setup.h"
+#include <errno.h>
+#include <string.h>
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
@@ -154,10 +161,12 @@ enum {
 #endif // !WX_PRECOMP
 
 #include  "wx/filename.h"
+
 #include  "CFile.h"
-#include  "wx/filefn.h"
 #include  "xmule.h"
 
+#include  "wx/filefn.h"
+
 #ifdef __WXMSW__
 #	include "wx/msw/mslu.h"
 #endif
@@ -361,8 +370,6 @@ bool CFile::Flush()
 // ----------------------------------------------------------------------------
 // seek
 // ----------------------------------------------------------------------------
-#include <errno.h>
-#include <string.h>
 
 // seek
 off_t CFile::Seek(off_t ofs, wxSeekMode mode)
