@@ -15,14 +15,18 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "SafeFile.h"
-#include "ClientCredits.h"
-#include "opcodes.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "SafeFile.h"
+#	include "ClientCredits.h"
+#	include "opcodes.h"
+#endif
+
 #include <math.h>
-#include "/usr/include/time.h"
+#include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
