@@ -18,12 +18,15 @@
 // ClientDetailDialog.cpp : implementation file
 //
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "ClientDetailDialog.h"
-#include "otherfunctions.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ClientDetailDialog.h"
+#	include "otherfunctions.h"
+#	include "muuli_wdr.h"
+#endif
 
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
@@ -35,7 +38,7 @@
 
 // CClientDetailDialog dialog
 
-#define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
+#define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
 #define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
 
@@ -75,8 +78,6 @@ void CClientDetailDialog::OnBnClose(wxEvent& evt)
   EndModal(0);
 }
 
-#define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
-
 BOOL CClientDetailDialog::OnInitDialog(){
 	Localize();
 	char buffer[100];
