@@ -16,12 +16,16 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 //#include "stdafx.h"
-#include "wintypes.h"
-#include "UploadQueue.h"
-#include "ClientList.h"
-#include "xmule.h"
-#include "otherfunctions.h"
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "UploadQueue.h"
+#	include "ClientList.h"
+#	include "xmule.h"
+#	include "otherfunctions.h"
+#endif
 
 CClientList::CClientList(){
 }
