@@ -1,11 +1,15 @@
 // CommentDialog.cpp : implementation file 
 // 
 
-//#include "stdafx.h" 
-#include "wintypes.h"
-#include "xmule.h" 
-#include "CommentDialog.h" 
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h" 
+#	include "CommentDialog.h" 
+#	include "muuli_wdr.h"
+#endif
+
 #include <wx/settings.h>
 // CommentDialog dialog 
 
