@@ -1,11 +1,15 @@
 
-//#include "stdafx.h" 
-#include "wintypes.h"
-#include "xmule.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "CommentDialogLst.h"
+#	include "muuli_wdr.h"
+#endif
+
 #include <wx/dialog.h>
 #include <wx/settings.h>
-#include "CommentDialogLst.h"
-#include "muuli_wdr.h"
 
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
