@@ -15,17 +15,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ListenSocket.h"
+#	include "updownclient.h"
+#	include "PartFile.h"
+#	include "opcodes.h"
+#	include "packets.h"
+#	include "xmule.h"
+#endif
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "ListenSocket.h"
 #include <zlib.h>
-#include "updownclient.h"
-#include "PartFile.h"
-#include "opcodes.h"
-#include "packets.h"
-#include "xmule.h"
 
 
 //	members of CUpDownClient
@@ -143,13 +146,12 @@ bool CUpDownClient::IsSourceRequestAllowed() {
 }
 
 void CUpDownClient::SendFileRequest(){
-	if(!reqfile) {
+	if(!reqfile)
 		return;
-	}
 	AddAskedCountDown();
 	CMemFile* data = new CMemFile();
 	data->Write(reqfile->GetFileHash(),16);
-	if( GetExtendedRequestsVersion() > 0 ) {
+	if( GetExtendedRequestsVersion() > 0 ){
 		reqfile->WritePartStatus(data);
 	}
 	Packet* packet = new Packet(data);
@@ -166,9 +168,8 @@ void CUpDownClient::SendFileRequest(){
 		socket->SendPacket(packet, true);
 		delete data;
 	}
-	if ( IsEmuleClient() ) {
+	if( IsEmuleClient() )
 		SetRemoteQueueFull( true );
-	}
 	SetRemoteQueueRank(0);
 	
 	if(IsSourceRequestAllowed()) {
