@@ -16,22 +16,22 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 // DownloadListCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "DownloadListCtrl.h"
-#include "otherfunctions.h"
-#include "updownclient.h"
-#include "opcodes.h"
-#include "ClientDetailDialog.h"
-#include "FileDetailDialog.h"
-#include "CommentDialogLst.h"
-
-#include "muuli_wdr.h"
-
-#include "../config.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "DownloadListCtrl.h"
+#	include "otherfunctions.h"
+#	include "updownclient.h"
+#	include "opcodes.h"
+#	include "ClientDetailDialog.h"
+#	include "FileDetailDialog.h"
+#	include "CommentDialogLst.h"
+#	include "muuli_wdr.h"
+#	include "config.h"
+#endif
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
@@ -52,6 +52,7 @@
 // lagloose
 #include <wx/font.h>
 // end lagloose
+#include <wx/dcmemory.h>
 
 //#define DLC_DT_TEXT (DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS)
 
@@ -164,8 +165,6 @@ CDownloadListCtrl::~CDownloadListCtrl()
 	delete m_hilightUnfocusBrush;
 }
 
-#include <wx/dcmemory.h>
-
 void CDownloadListCtrl::HideSources(CPartFile * toCollapse, bool isShift, bool isCtrl, bool isAlt)
 {
 	int pre, post;
@@ -402,7 +401,7 @@ void CDownloadListCtrl::OnNMRclick(wxListEvent & evt)
 			menu->Enable(MP_STOP, ((file->GetStatus() != PS_PAUSED && file->GetStatus() != PS_ERROR) ? MF_ENABLED : MF_GRAYED));
 			menu->Enable(MP_RESUME, ((file->GetStatus() == PS_PAUSED) ? MF_ENABLED : MF_GRAYED));
 			menu->Enable(MP_OPEN, ((file->GetStatus() == PS_COMPLETE) ? MF_ENABLED : MF_GRAYED));	//<<--9/21/02
-			menu->SetLabel(MP_PREVIEW, wxString::Format(_T("Preview [%s]"), file->GetPartMetFileName()));
+			menu->SetLabel(MP_PREVIEW, wxString::Format(_("Preview [%s]"), file->GetPartMetFileName()));
 			menu->Enable(MP_PREVIEW, ((file->PreviewAvailable())? MF_ENABLED : MF_GRAYED));
 
 			/* Razor 1a - Modif by MikaelB
