@@ -14,10 +14,13 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "DownloadQueue.h"
-#include "updownclient.h"
-#include "PartFile.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "DownloadQueue.h"
+#	include "updownclient.h"
+#	include "PartFile.h"
+#endif
 
 #include <wx/filename.h>
 #include <wx/listimpl.cpp>
@@ -389,20 +392,15 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* sou
 		return;
 
 	// use this for client which are already know (downloading for example)
-	for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos)) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
 		CPartFile* cur_file = filelist.GetAt(pos);
-		for (int sl=0;sl<SOURCESSLOTS;sl++) {
-			if (!cur_file->srclists[sl].IsEmpty()) {
-				if (cur_file->srclists[sl].Find(source)) {
-					if (cur_file == sender) {
-						return;
-					}
-					if (source->AddRequestForAnotherFile(sender)) {
-						theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
-					}	
-					return;
-				}
-			}
+		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
+		if (cur_file->srclists[sl].Find(source)){
+			if (cur_file == sender)
+				return;
+			if (source->AddRequestForAnotherFile(sender))
+				theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
+			return;
 		}
 	}
 	source->SetDownloadFile(sender);
