@@ -15,16 +15,24 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#define MAX_SIZE 2000000
-#include "EMSocket.h"
-#include "opcodes.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "EMSocket.h"
+#	include "opcodes.h"
+#endif
+
+#ifndef MAX_SIZE
+#	define MAX_SIZE 2000000
+#endif
+
 
 IMPLEMENT_DYNAMIC_CLASS(CEMSocket,wxSocketClient)
 
-//#include <io.h>
 #include <fcntl.h>
 #include <sys/stat.h>
+#include <signal.h>
+
 #if 0
 namespace {
 	inline void EMTrace(char* fmt, ...) {
@@ -440,7 +448,6 @@ void CEMSocket::OnSend(int nErrorCode){
 	} 
 }
 
-#include <signal.h>
 int CEMSocket::Send(char* lpBuf,int nBufLen,int nFlags){
   assert (sendbuffer == NULL || lpBuf == NULL );
   if (lpBuf){
