@@ -16,16 +16,17 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 // FileDetailDialog.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "FileDetailDialog.h"
-#include "otherfunctions.h"
-//#include "FileInfoDialog.h"
-#include "CommentDialogLst.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "FileDetailDialog.h"
+#	include "otherfunctions.h"
+#	include "CommentDialogLst.h"
+#	include "muuli_wdr.h"
+#endif
 
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
