@@ -15,15 +15,18 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 // FriendListCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "FriendListCtrl.h"
-#include "Friend.h"
-#include "ClientDetailDialog.h"
-#include "AddFriend.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "FriendListCtrl.h"
+#	include "Friend.h"
+#	include "ClientDetailDialog.h"
+#	include "AddFriend.h"
+#endif
+
 // CFriendListCtrl
 
 BEGIN_EVENT_TABLE(CFriendListCtrl,CMuleListCtrl)
