@@ -15,11 +15,14 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "StdAfx.h"
-#include "wintypes.h"
-#include "IPFilter.h"
-#include "xmule.h"
-#include "otherfunctions.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "IPFilter.h"
+#	include "xmule.h"
+#	include "otherfunctions.h"
+#endif
 
 CIPFilter::CIPFilter(){
 	lasthit="";
