@@ -17,16 +17,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "KnownFile.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#	include "xmule.h"
+#	include "ini2.h"
+#endif
+
+#include "MD5Sum.h"
 
-//#include "stdafx.h"
-#include "KnownFile.h"
-#include "opcodes.h"
-#include "otherfunctions.h"
-//#include <io.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include "xmule.h"
-#include "ini2.h"
 	
 static void MD4Transform(uint32 Hash[4], uint32 x[16]);
 
