@@ -16,12 +16,15 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "KnownFileList.h"
-#include "KnownFile.h"
-//include "opcodes.h"
-#include "xmule.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "KnownFileList.h"
+#	include "KnownFile.h"
+#	include "xmule.h"
+#endif
+
 #include <wx/utils.h>
 
 static wxString KnownFileHash(const char* filename, uint32 date, uint32 size)
