@@ -19,32 +19,37 @@
 #ifndef KNOWNFILELIST_H
 #define KNOWNFILELIST_H
 
-#include "KnownFile.h"
-//#include <afxmt.h>
+class CKnownFile;
 #include "xmule.h"
 
-#include <wx/list.h>
-WX_DECLARE_LIST(CKnownFile,KnownFileList);
+#include <wx/hashmap.h>
+WX_DECLARE_HASH_MAP(wxString,CKnownFile*,wxStringHash,wxStringEqual,KnownFileMap);
 
-//class CKnownFileList : public CArray<CKnownFile*,CKnownFile*>
-class CKnownFileList : public KnownFileList
+class CKnownFileList
 {
-	friend class CSharedFilesWnd;
-	friend class CFileStatistic;
+//	friend class CSharedFilesWnd;
+//	friend class CFileStatistic;
 public:
 	CKnownFileList(char* in_appdir);
 	~CKnownFileList();
-	void	SafeAddKFile(CKnownFile* toadd);
+	bool	SafeAddKFile(CKnownFile* toadd);
 	bool	Init();
 	void	Save();
 	void	Clear();
 	CKnownFile*	FindKnownFile(char* filename,uint32 in_date,uint32 in_size);
-	wxMutex	list_mut;
-private:
-	char*	appdir;
+
+
 	uint16 requested;
 	uint32 transfered;
 	uint16 accepted;
+
+private:
+	wxMutex	list_mut;
+
+	bool	Append(CKnownFile*);
+	char*	appdir;
+
+	KnownFileMap	m_map;
 };
 
 
