@@ -15,18 +15,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 // ListenSocket.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "ListenSocket.h"
-#include "opcodes.h"
-#include "KnownFile.h"
-#include "SharedFileList.h"
-#include "UploadQueue.h"
-#include "updownclient.h"
-#include "ClientList.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ListenSocket.h"
+#	include "opcodes.h"
+#	include "KnownFile.h"
+#	include "SharedFileList.h"
+#	include "UploadQueue.h"
+#	include "updownclient.h"
+#	include "ClientList.h"
+#endif
 
 #ifndef ID_SOKETTI
 #define ID_SOKETTI 7772
@@ -37,7 +39,6 @@
 
 IMPLEMENT_DYNAMIC_CLASS(CClientReqSocket,CEMSocket)
 
-#include "ListenSocket.h"
 // CClientReqSocket
 CClientReqSocket::CClientReqSocket(CPreferences* in_prefs,CUpDownClient* in_client){
 	app_prefs = in_prefs;
