@@ -26,6 +26,11 @@ public:
 	CCKey(uchar* key = 0)		{m_key = key;}
 	CCKey(const CCKey& k1)		{m_key = k1.m_key;}
 
+	friend bool operator<(const CCKey& k1,const CCKey&k2)
+	{
+		return memcmp(k1.m_key, k2.m_key, 16) < 0;
+	}
+
 	CCKey& operator=(const CCKey& k1)						{m_key = k1.m_key; return *this; }
 	friend bool operator==(const CCKey& k1,const CCKey& k2)	{return !memcmp(k1.m_key,k2.m_key,16);}
 	
@@ -38,4 +43,5 @@ template<> inline unsigned int HashKey(CCKey key){
 	   hash += (key.m_key[i]+1)*((i*i)+1);
    return hash;
 };
+
 #endif
