@@ -2,7 +2,7 @@
 // Name:        notebook.cpp
 // Purpose:
 // Author:      Robert Roebling
-// Id:          $Id: MuleNotebook.cpp,v 1.6 2003/06/21 23:33:27 madcat_ Exp $
+// Id:          $Id: MuleNotebook.cpp,v 1.7 2004/01/23 13:17:18 HopeSeekr Exp $
 // Copyright:   (c) 1998 Robert Roebling, Vadim Zeitlin
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -11,8 +11,12 @@
 #pragma implementation "MuleNotebook.h"
 #endif
 
-#include "CMuleNotebookBase.h"
-#include "xmule.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "CMuleNotebookBase.h"
+#	include "xmule.h"
+#endif
 
 #if wxUSE_NOTEBOOK
 #include "wx/bitmap.h"
