@@ -1,11 +1,15 @@
 // OScopeCtrl.cpp : implementation file//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "OScopeCtrl.h"
+#endif
+
 #include <math.h>
 
-#include "OScopeCtrl.h"
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
