@@ -1,10 +1,12 @@
 // PPgGeneral.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "PPgGeneral.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "PPgGeneral.h"
+#endif
 
 #include <wx/checkbox.h>
 #include <wx/notebook.h>
@@ -87,8 +89,6 @@ BEGIN_MESSAGE_MAP(CPPgGeneral, CPropertyPage)
 END_MESSAGE_MAP()
 #endif
 
-#include <wx/checkbox.h>
-
 void CPPgGeneral::LoadSettings(void)
 {
   // Barry - Controls depth of 3d colour shading
