@@ -1,10 +1,12 @@
 // CPPgGuiTweaks implementation file
-//
 
-
-#include "wintypes.h"
-#include "xmule.h"
-#include "PPgGuiTweaks.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "PPgGuiTweaks.h"
+#endif
 
 #include <wx/slider.h>
 #include "wx/xrc/xmlres.h"
