@@ -11,10 +11,16 @@
 //You should have received a copy of the GNU General Public License
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "PPgNotify.h"
+
+
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "PPgNotify.h"
+#endif
+
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
 
