@@ -1,10 +1,12 @@
 // PgTweaks.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "PPgTweaks.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "PPgTweaks.h"
+#endif
 
 #include <wx/slider.h>
 #include "wx/xrc/xmlres.h"
