@@ -29,16 +29,20 @@
 #include <sys/param.h>
 #endif
 
-#include "PartFile.h"
-#include "xmule.h"
-#include "updownclient.h"
-#include "otherfunctions.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "PartFile.h"
+#	include "xmule.h"
+#	include "updownclient.h"
+#	include "otherfunctions.h"
+#	include "ED2KLink.h"
+#	include "Preview.h"
+#	include "AddFileThread.h"
+#	include "ini2.h"
+#endif
+
 #include <math.h>
-#include "ED2KLink.h"
-#include "Preview.h"
-#include "AddFileThread.h"
-#include <wx/filename.h>
-#include "ini2.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -46,6 +50,8 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
+#include <wx/filename.h>
+
 #define PROGRESS_HEIGHT 3
 
 void dump16f(FILE*f, uchar* d16)
