@@ -1,12 +1,15 @@
 // PreferencesDlg.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "PreferencesDlg.h"
-#include "muuli_wdr.h"
-#include "Wizard.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "PreferencesDlg.h"
+#	include "muuli_wdr.h"
+#	include "Wizard.h"
+#endif
+
 #include "wx/xrc/xmlres.h"
 #include "wx/xrc/xh_all.h"
 
