@@ -16,17 +16,18 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 // QueueListCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "QueueListCtrl.h"
-#include "otherfunctions.h"
-#include "opcodes.h"
-#include "ClientDetailDialog.h"
-
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "QueueListCtrl.h"
+#	include "otherfunctions.h"
+#	include "opcodes.h"
+#	include "ClientDetailDialog.h"
+#	include "muuli_wdr.h"
+#endif
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
