@@ -15,9 +15,12 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "SafeFile.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "SafeFile.h"
+#endif
 
 CSafeFile::CSafeFile(LPCSTR lpszFileName,UINT nOpenFlags)
 :CFile(lpszFileName,(CFile::OpenMode)nOpenFlags)
