@@ -17,19 +17,19 @@
 
 
 // SearchDlg.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "SearchDlg.h"
-#include "packets.h"
-#include "server.h"
-#include "opcodes.h"
-#include "otherfunctions.h"
-#include "ED2KLink.h"
-
-// CSearchDlg dialog
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "SearchDlg.h"
+#	include "packets.h"
+#	include "server.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#	include "ED2KLink.h"
+#	include "muuli_wdr.h"
+#endif
 
 #include "pixmaps/close.xpm"
 #include "pixmaps/close_hi.xpm"
