@@ -17,14 +17,15 @@
 
 
 // SearchListCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "SearchListCtrl.h"
-#include "otherfunctions.h"
-
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "SearchListCtrl.h"
+#	include "otherfunctions.h"
+#	include "muuli_wdr.h"
+#endif
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
