@@ -30,11 +30,14 @@
 #include <sys/param.h>
 #endif
 
-//#include "stdafx.h"
-#include "ServerList.h"
-#include "xmule.h"
-#include "HTTPDownloadDlg.h"
-#include "SafeFile.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "ServerList.h"
+#	include "xmule.h"
+#	include "HTTPDownloadDlg.h"
+#	include "SafeFile.h"
+#endif
 
 #include <wx/msgdlg.h>
 
@@ -366,11 +369,13 @@ CServerList::~CServerList(){
 #include <wx/txtstrm.h>
 #include <wx/wfstream.h>
 
+#ifndef MAX_PATH
 // *BSD compatibility
-#if (defined(BSD) && (BSD >= 199103))
-#define MAX_PATH MAXPATHLEN
-#else
-#define MAX_PATH 1024
+#  if (defined(BSD) && (BSD >= 199103))
+#     define MAX_PATH MAXPATHLEN
+#  else
+#     define MAX_PATH 1024
+#  endif
 #endif
 
 void CServerList::AddServersFromTextFile(CString strFilename,bool isstaticserver) {
