@@ -17,12 +17,14 @@
 
 
 // ServerListCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "ServerListCtrl.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "ServerListCtrl.h"
+#	include "muuli_wdr.h"
+#endif
 
 // CServerListCtrl
 
