@@ -15,30 +15,22 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "ListenSocket.h"
-#include "opcodes.h"
-#include "KnownFile.h"
-#include "SharedFileList.h"
-#include "UploadQueue.h"
-#include "updownclient.h"
-#include "ClientList.h"
-#include "ServerSocket.h"
-
-#if 0
-#include "xmule.h"
-#include "packets.h"
-#include "ServerSocket.h"
-#include "xmuleDlg.h"
-#include "opcodes.h"
-#include "SearchList.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ListenSocket.h"
+#	include "opcodes.h"
+#	include "KnownFile.h"
+#	include "SharedFileList.h"
+#	include "UploadQueue.h"
+#	include "updownclient.h"
+#	include "ClientList.h"
+#	include "ServerSocket.h"
 #endif
 
 #include <time.h>
-//#include <afxmt.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -232,7 +224,7 @@ bool CServerSocket::ProcessPacket(char* packet, int32 size, int8 opcode){
 			case OP_SEARCHRESULT:{
 				theApp.xmuledlg->searchwnd->LocalSearchEnd(theApp.searchlist->ProcessSearchanswer(packet,size));
 				theApp.downloadqueue->AddDownDataOverheadServer(size);
- 				CServer* cur_srv = (serverconnect) ? serverconnect->GetCurrentServer() : NULL;
+				CServer *cur_srv = (serverconnect) ? serverconnect->GetCurrentServer() : NULL;
 				break;
 			}
 			case OP_FOUNDSOURCES:{
@@ -393,18 +385,18 @@ void CServerSocket::OnError(int nErrorCode){
 
 void CServerSocket::PacketReceived(Packet* packet) {
 	if (packet->prot == OP_PACKEDPROT) {
-			uint32 uComprSize = packet->size;
-			if (!packet->UnPackPacket(250000)) {
-				theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
-				return;
-			}
-			packet->prot = OP_EDONKEYPROT;
-		} else if (packet->prot == OP_EDONKEYPROT) {
-			ProcessPacket(packet->pBuffer,packet->size,packet->opcode);
-		} else {
-			theApp.xmuledlg->AddDebugLogLine(false,_T("Received server TCP packet with unknown protocol: protocol=0x%02x  opcode=0x%02x  size=%u"), packet ? packet->prot : 0, packet ? packet->opcode : 0, packet ? packet->size : 0);
+		uint32 uComprSize = packet->size;
+		if (!packet->UnPackPacket(25000)) {
 			theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
+			return;
 		}
+		packet->prot = OP_EDONKEYPROT;
+	} else if (packet->prot == OP_EDONKEYPROT) {
+		ProcessPacket(packet->pBuffer, packet->size, packet->opcode);
+	} else {
+		theApp.xmuledlg->AddDebugLogLine(false, _("Received server TCP packet with unknown protocol: protocol=0x%02x  opcode=0x%02x  size=%u"), packet ? packet->prot : 0, packet ? packet->opcode : 0, packet ? packet->size : 0);
+		theApp.downloadqueue->AddDownDataOverheadServer(packet->size);
+	}
 }
 
 void CServerSocket::OnClose(int nErrorCode){
