@@ -17,18 +17,18 @@
 
 
 // ServerWnd.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "ServerWnd.h"
-//#include "HttpDownloadDlg.h"
-#include "HTTPDownloadDlg.h"
-#include "config.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "ServerWnd.h"
+#	include "HTTPDownloadDlg.h"
+#	include "config.h"
+#	include "muuli_wdr.h"
+#endif
 
-// CServerWnd dialog
-#include "muuli_wdr.h"
 #include <wx/settings.h>
 
 //IMPLEMENT_DYNAMIC(CServerWnd, CDialog)
@@ -56,7 +56,7 @@ CServerWnd::CServerWnd(wxWindow* pParent /*=NULL*/)
   serverlistctrl=list;
 
   wxTextCtrl* cv=(wxTextCtrl*)FindWindowByName("serverInfo");
-  cv->AppendText(wxString(_("This is "))+wxString("xMule")+wxString(" ")+wxString(VERSION)+wxString(_(" (based on "))+wxString(_("eMule"))+wxString(")\n"));
+  cv->AppendText(wxString(_("This is "))+wxString("xMule")+wxString(" ")+PACKAGE_VERSION+wxString(_(" (based on "))+wxString(_("eMule"))+wxString(")\n"));
   cv->AppendText(wxString(_("Visit http://www.xmule.org to check if a new version is available.\n")));
 //  cv->AppendText(GetResString(IDS_EMULEW)+wxString(" "));
 //  cv->AppendText(GetResString(IDS_EMULEW3)+wxString(" "));
