@@ -17,14 +17,16 @@
 
 
 // SharedFilesCtrl.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "SharedFilesCtrl.h"
-#include "otherfunctions.h"
-#include "muuli_wdr.h"
-#include "CommentDialog.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "SharedFilesCtrl.h"
+#	include "otherfunctions.h"
+#	include "muuli_wdr.h"
+#	include "CommentDialog.h"
+#endif
 
 // CSharedFilesCtrl
 
