@@ -17,14 +17,17 @@
 
 
 // SharedFilesWnd.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "SharedFilesWnd.h"
-#include "otherfunctions.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "SharedFilesWnd.h"
+#	include "otherfunctions.h"
+#	include "muuli_wdr.h"
+#endif
+
 #include <wx/settings.h>
 
 // CSharedFilesWnd dialog
