@@ -16,14 +16,18 @@
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 // StatisticsDlg.cpp : implementation file
-//
-//#include "stdafx.h"
-#include "xmule.h"
-#include "StatisticsDlg.h"
-#include "UploadQueue.h"
-#include "ColorFrameCtrl.h"
-#include "WebServer.h"
-#include "muuli_wdr.h"
+
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "StatisticsDlg.h"
+#	include "UploadQueue.h"
+#	include "ColorFrameCtrl.h"
+#	include "WebServer.h"
+#	include "muuli_wdr.h"
+#endif
+
 #include <wx/settings.h>
 
 #define ID_EXPORT_HTML 20001
