@@ -17,15 +17,19 @@
 
 
 // TransferWnd.cpp : implementation file
-//
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "TransferWnd.h"
-#include "CatDialog.h"
-#include "muuli_wdr.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "TransferWnd.h"
+#	include "CatDialog.h"
+#	include "muuli_wdr.h"
+#endif
+
 #include <wx/settings.h>
+#include <wx/splitter.h>
 
 // CTransferWnd dialog
 
@@ -39,7 +43,7 @@ END_EVENT_TABLE()
 
   // handled in controls ProcessEvents()
   //  EVT_MENU(MP_SWITCHCTRL,CTransferWnd::SwitchUploadList)
-#include <wx/splitter.h>
+
 //IMPLEMENT_DYNAMIC(CTransferWnd, CDialog)
 CTransferWnd::CTransferWnd(wxWindow* pParent /*=NULL*/)
 	: wxPanel(pParent,CTransferWnd::IDD)
