@@ -15,12 +15,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "packets.h"
+#	include "UDPSocket.h"
+#endif
 
-#include "xmule.h"
-#include "packets.h"
-#include "UDPSocket.h"
 #include <netdb.h>
 #include <pthread.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+
 
 static pthread_attr_t attr;//=PTHREAD_CREATE_DETACHED;
 
@@ -240,10 +248,6 @@ bool  CUDPSocket::Create(){
 }
 #endif
 
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
 void CUDPSocket::OnReceive(int nErrorCode){
 	char buffer[5000];
 	wxString serverbuffer;
