@@ -15,16 +15,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "wintypes.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "updownclient.h"
+#	include "opcodes.h"
+#	include "packets.h"
+#	include "xmule.h"
+#	include "UploadQueue.h"
+#	include "otherstructs.h"
+#	include "otherfunctions.h"
+#endif
+
 #include <zlib.h>
-#include "updownclient.h"
-#include "opcodes.h"
-#include "packets.h"
-#include "xmule.h"
-#include "UploadQueue.h"
-#include "otherstructs.h"
-#include "otherfunctions.h"
 
 //	members of CUpDownClient
 //	which are mainly used for uploading functions 
