@@ -15,17 +15,22 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "UploadQueue.h"
-#include "packets.h"
-#include "xmule.h"
-#include "KnownFile.h"
-#include "ListenSocket.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "UploadQueue.h"
+#	include "packets.h"
+#	include "xmule.h"
+#	include "KnownFile.h"
+#	include "ListenSocket.h"
+#	include "ini2.h"
+#endif
+
 #include <string.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include "ini2.h"
+
 #define ID_UQTIMER 59742
 
 #ifdef _DEBUG
