@@ -1,10 +1,14 @@
-//#include "StdAfx.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "WebServer.h"
-#include "XBMDraw.h"
-#include "ED2KLink.h"
-#include "MD5Sum.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "WebServer.h"
+#	include "XBMDraw.h"
+#	include "ED2KLink.h"
+#	include "MD5Sum.h"
+#endif
+
 #include <stdlib.h>
 #include <wx/wfstream.h>
 #include <wx/txtstrm.h>
