@@ -1,19 +1,19 @@
 // ws2.cpp : Defines the entry point for the application.
-//
 
-//#include <stdafx.h>
-//#pragma comment(lib, "ws2_32.lib")
-#include "wintypes.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "WebSocket.h"
+#	include "WebServer.h"
+#	include "xmule.h"
+#endif
 
 #include <stdlib.h> // for atol function
 #include <errno.h>
 #include <pthread.h>
 #include <netinet/in.h>
 
-#include "WebSocket.h"
-#include "WebServer.h"
-#include "xmule.h"
-
 #ifdef _DEBUG
 #undef THIS_FILE
 static char THIS_FILE[]=__FILE__;
