@@ -2,9 +2,12 @@
 //
 //////////////////////////////////////////////////////////////////////
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "XBMDraw.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "XBMDraw.h"
+#endif
 
 #ifdef _DEBUG
 #undef THIS_FILE
