@@ -1,3 +1,5 @@
+#ifndef _inetdownload_h
+#define _inetdownload_h
 unsigned char inetDownload[]={
 	0x47,0x49,0x46,0x38,0x39,0x61,0x10,0x1,0x3c,0x0,0xf3,0x0,0x0,0xff,0x0,0xff,0xff,0xff,0xff,0x80,0x80,0x80,0x0,0x0,0x0,0xc0,0xc0,0xc0,0xff,0xff,0x0,0x0,0x80,0x0,0x0,0x0,0xff,0x0,0xff,0x0,0x0,0x0,0x80,0x80,0x80,0x0,0x0,0xff,0xff,0x0,
 	0x80,0x80,0xff,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x21,0xff,0xb,0x4e,0x45,0x54,0x53,0x43,0x41,0x50,0x45,0x32,0x2e,0x30,0x3,0x1,0x0,0x0,0x0,0x21,0xf9,0x4,0x9,0x7,0x0,0x0,0x0,0x2c,0x0,0x0,0x0,0x0,0x10,0x1,0x3c,0x0,0x0,0x4,0xff,
@@ -379,3 +381,5 @@ unsigned char inetDownload[]={
 	0x68,0xa4,0x40,0xec,0x39,0x69,0x86,0x50,0x82,0x70,0x65,0x44,0x98,0x8e,0xca,0xa9,0x15,0x6c,0x1e,0x9a,0x5d,0xa8,0x22,0x8c,0xea,0xea,0xa6,0xa7,0xa,0x21,0x80,0x2,0xb4,0xd6,0x6a,0xeb,0xad,0xb8,0xe2,0xa,0x6b,0xac,0x64,0xbc,0xea,0xeb,0xaf,0xc0,0xee,0xca,
 	0xeb,0xb0,0xc4,0x16,0x6b,0xec,0xb1,0xc8,0x26,0xab,0xec,0xb2,0xcc,0x36,0xeb,0xec,0x4,0xb3,0xc3,0x46,0x0,0x0,0x3b,0xff,
 };
+#endif
+
