@@ -2,12 +2,15 @@
 //
 //////////////////////////////////////////////////////////////////////
 
-//#include "stdafx.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#include "ini2.h"
 #include "wintypes.h"
+#endif
+
 #include <wx/string.h>
 #include <wx/window.h>
-#include "ini2.h"
-
 #include <wx/config.h>
 
 #ifdef _DEBUG
