@@ -15,10 +15,14 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "wintypes.h"
-#include "otherfunctions.h"
-#include "xmule.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "wintypes.h"
+#	include "otherfunctions.h"
+#	include "xmule.h"
+#endif
+
 #include <wx/utils.h>
 
 #include "strings.en"
