@@ -15,10 +15,12 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
-//#include "stdafx.h"
-#include "packets.h"
-#include "otherfunctions.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "packets.h"
+#	include "otherfunctions.h"
+#endif
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -159,7 +161,7 @@ void Packet::PackPacket(){
 	assert (!m_bSplitted);
 	BYTE* output = new BYTE[size+300];
 	uLongf newsize = size+300;
-	uint16 result = compress2(output,&newsize,(BYTE*)pBuffer,size,Z_BEST_COMPRESSION);
+	uint16 result = compress2(output, &newsize, (BYTE*)pBuffer, size, Z_BEST_COMPRESSION);
 	if (result != Z_OK || size <= newsize){
 		delete[] output;
 		return;
@@ -170,7 +172,7 @@ void Packet::PackPacket(){
 	m_bPacked = true;
 }
 
-bool Packet::UnPackPacket(UINT uMaxDecompressedSize){
+bool Packet::UnPackPacket(UINT uMaxDecompressedSize) {
 	assert ( prot == OP_PACKEDPROT); 
 	uint32 nNewSize = size*10+300;
 	if (nNewSize > uMaxDecompressedSize)
