@@ -15,12 +15,15 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "server.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#	include "xmule.h"
+#endif
 
-//#include "stdafx.h"
-#include "server.h"
-#include "opcodes.h"
-#include "otherfunctions.h"
-#include "xmule.h"
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
