@@ -15,18 +15,20 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "packets.h"
+#	include "ServerSocket.h"
+#	include "sockets.h"
+#	include "xmuleDlg.h"
+#	include "opcodes.h"
+#	include "SearchList.h"
+#	include "UDPSocket.h"
+#endif
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "packets.h"
-#include "ServerSocket.h"
-#include "sockets.h"
-#include "xmuleDlg.h"
-#include "opcodes.h"
-#include "SearchList.h"
 #include <time.h>
-//#include <afxmt.h>
-#include "UDPSocket.h"
 
 // CServerConnect
 
@@ -170,7 +172,7 @@ void CServerConnect::ConnectionEstablished(CServerSocket* sender){
 		tag->WriteTagToFile(data);
 		delete tag;
 
-		tag = new CTag(0x20,0x00000001); // I am zlib aware! :-)
+		tag = new CTag(0x20, 0x00000001); // I am zlib aware! :-))
 		tag->WriteTagToFile(data);
 		delete tag;
 
