@@ -15,33 +15,39 @@
 //along with this program; if not, write to the Free Software
 //Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "xmuleDlg.h"
-#include "opcodes.h"
-#include "IPFilter.h"
-#include "WebServer.h"
-//#include "mdump.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "config.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
+#	include "opcodes.h"
+#	include "IPFilter.h"
+#	include "WebServer.h"
+#	include "muuli_wdr.h"
+#endif
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
 #endif
 
+#include <wx/ipc.h>
 #include <wx/config.h>
 #include <wx/clipbrd.h>
 #include <wx/socket.h>
 #include <wx/splash.h>
-#include "muuli_wdr.h"
 
 #include <wx/filesys.h>
 #include <wx/fs_zip.h>
+#include <wx/utils.h>
 #include "wx/xrc/xmlres.h"
 
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include <config.h>
+#include <gdk/gdk.h>
+#include <gtk/gtk.h>
 
 IMPLEMENT_APP(CxmuleApp)
 
@@ -145,7 +151,7 @@ int CxmuleApp::OnExit()
 //CxmuleApp theApp;
 
 // IPC classes
-#include <wx/ipc.h>
+
 class MuleConnection:public wxConnection 
 {
   public:
@@ -290,7 +296,7 @@ bool CxmuleApp::OnInit()
 
 	for (int i = 1; i < argc; i++) {
 		if (strncmp(argv[i], "--version", 7) == 0) {
-			printf("%s version %s\n", PACKAGE, VERSION);
+			printf("%s version %s\n", PACKAGE_NAME, PACKAGE_VERSION);
 			sleep(1);
 			exit(0);
 		}
@@ -355,12 +361,11 @@ bool CxmuleApp::OnInit()
 	m_locale.AddCatalogLookupPathPrefix(LOCALEDIR);
 	m_locale.AddCatalog(PACKAGE);
 
-	CxmuleDlg *dlg = new CxmuleDlg(NULL, wxString::Format(wxT("%s v%s"), wxT(PACKAGE), wxT(VERSION)));
+	CxmuleDlg *dlg = new CxmuleDlg(NULL, wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
 	xmuledlg = dlg;
 	dlg->Show(TRUE);
 
 	// Madcat - Check if prefs can be found at ~/.lmule and rename as neccesery.
-#include <wx/utils.h>
 
 	wxString OldPrefDir = getenv("HOME") + wxString("/.lmule");
 	wxString NewPrefDir = getenv("HOME") + wxString("/.xMule");
@@ -374,7 +379,7 @@ bool CxmuleApp::OnInit()
 	glob_prefs = new CPreferences();
 	xmuledlg->preferenceswnd->SetPrefs(glob_prefs);
 
-	xmuledlg->createSystray(wxString::Format(wxT("%s v%s"), wxT(PACKAGE), wxT(VERSION)));
+	xmuledlg->createSystray(wxString::Format(wxT("%s v%s"),	wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
 
 	// splashscreen
 	if (theApp.glob_prefs->UseSplashScreen() && !theApp.glob_prefs->GetStartMinimized()) {
@@ -791,7 +796,7 @@ void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 	xmulesig_out.Write("\n",1);
 
 	// xmule version 
-	sprintf(buffer,"%s",VERSION);
+	sprintf(buffer,"%s", PACKAGE_VERSION);
 	xmulesig_out.Write(buffer, strlen(buffer));
 	xmulesig_out.Write("\n",1);
 
@@ -840,8 +845,6 @@ void CxmuleApp::OnFatalException()
 #define wxGTK_WINDOW 1
 #define SHIFT (8*(sizeof(short int)-sizeof(char)))
 
-#include <gdk/gdk.h>
-#include <gtk/gtk.h>
 static bool GetColourWidget(int &red, int &green, int &blue, int type)
 {
 	GtkWidget *widget;
