@@ -19,28 +19,30 @@
 // xmuleDlg.cpp : Implementierungsdatei
 //
 
-//#include "stdafx.h"
-#include "xmule.h"
-#include "xmuleDlg.h"
-#include "sockets.h"
-#include "KnownFileList.h"
-#include "KnownFile.h"
-#include "ServerList.h"
-#include "opcodes.h"
-#include "SharedFileList.h"
-#include "CreditsDlg.h"
-#include "ED2KLink.h"
-#include "UDPSocket.h"
-#include "math.h"
-//#include "SplashScreen.h"
-#pragma comment(lib, "winmm.lib")
-//#include "mmsystem.h"
-//#include "EnBitmap.h"
-#include "config.h"
-#include "AddFileThread.h"
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "xmule.h"
+#	include "xmuleDlg.h"
+#	include "sockets.h"
+#	include "KnownFileList.h"
+#	include "KnownFile.h"
+#	include "ServerList.h"
+#	include "opcodes.h"
+#	include "SharedFileList.h"
+#	include "CreditsDlg.h"
+#	include "ED2KLink.h"
+#	include "UDPSocket.h"
+#	include "config.h"
+#	include "AddFileThread.h"
+#	include "muuli_wdr.h"
+#	include "ServerSocket.h"
+#endif
+
+#include <errno.h>
+#include <math.h>
+#include <signal.h>
 
-#include "mmMultiButton.h"
-#include "muuli_wdr.h"
 #include <wx/splash.h>
 #include <wx/toolbar.h>
 #include <wx/utils.h>
@@ -55,7 +57,12 @@
 #define new DEBUG_NEW
 #endif
 
-#include "ServerSocket.h"
+#if wxMINOR_VERSION > 4
+#	define CLOSEBOX wxCLOSE_BOX
+#else
+#	define CLOSEBOX 0
+#endif
+
 #if 0
 #define ID_BUTTONCONNECT 42110
 #define ID_BUTTONSERVERS 42111
@@ -135,13 +142,6 @@ void muleDefaultToolbar( wxToolBar *parent )
 }
 
 // CxmuleDlg Dialog
-#include <signal.h>
-
-#if wxMINOR_VERSION > 4
-#define CLOSEBOX wxCLOSE_BOX
-#else
-#define CLOSEBOX 0
-#endif
 
 CxmuleDlg::CxmuleDlg(wxWindow* pParent, wxString title) 
   : wxFrame(pParent,CxmuleDlg::IDD,title,wxDefaultPosition,wxSize(800,520),
@@ -506,8 +506,6 @@ void CxmuleDlg::btnPreferences(wxEvent& ev)
   preferenceswnd->ShowModal();
 }
 
-#include "UDPSocket.h"
-#include <errno.h>
 void CxmuleDlg::socketHandler(wxSocketEvent& event)
 {
   if(!event.GetSocket())
